diy-django
==========

.. image:: http://img.shields.io/travis/collinanderson/diy-django.svg
.. image:: http://img.shields.io/pypi/v/diy-django.svg

http://diy-django.readthedocs.org

Features:

- Email as Username http://diy-django.readthedocs.org/en/latest/emailauth.html
- Markdown http://diy-django.readthedocs.org/en/latest/markdown.html
